@@ -64,6 +64,7 @@ class SwidgetWebsocket:
         try:
             headers = {'Connection': 'Upgrade'}
             async with self.session.ws_connect(self.uri, headers=headers, verify_ssl=False) as self.ws_client:
+                _LOGGER.error("AIOHTTP websocket connected")
                 self.state = STATE_CONNECTED
                 self.failed_attempts = 0
                 self.send_str(json.dumps({"type": "summary", "request_id": "1"}))
@@ -114,7 +115,7 @@ class SwidgetWebsocket:
                 await asyncio.sleep(5)
 
     async def send_str(self, message):
-        _LOGGER.error(f"Sending Message: {message}")
+        # _LOGGER.error(f"Sending Message: {message}")
         message = str(message)
         await self.ws_client.send_str(f'{message}')
 
